1. Home
  2. News
  3. Download
    1. Thunderbird Release Version
    2. Thunderbird 153 ESR (2026)
    3. Thunderbird 140 ESR (2025)
    4. Thunderbird Beta Version
    5. Language Pack (User Interface)
    6. Dictionaries (Spell Check)
  4. Help & Lexicon
    1. Instructions for Thunderbird
    2. Questions & Answers (FAQ) about Thunderbird
    3. Help for this Website
    4. Last Changes
  5. Forums
    1. Unresolved Threads
    2. Latest Posts
    3. Threads of the last 24 hours
  • Login
  • Register
  • 
  • Search
This Thread
  • Everywhere
  • This Thread
  • This Forum
  • Forum
  • Lexicon
  • Articles
  • Pages
  • More Options
  1. Thunderbird Mail DE
  2. Forum
  3. Hilfe zu Verschlüsselung & elektronische Signatur
  4. OpenPGP Verschlüsselung & Unterschrift
  5. Enigmail OpenPGP in Thunderbird-Versionen bis 68.*

Problem beim Entschlüsseln mit OpenPGP [erledigt]

  • Silberdrache
  • February 21, 2008 at 11:00 AM
  • Closed
  • Thread is Resolved
  • Silberdrache
    Junior Member
    Posts
    3
    Member since
    21. Feb. 2008
    • February 21, 2008 at 11:00 AM
    • #1

    Hallo,

    ich habe ein Problem beim Entschlüsseln einer Nachricht mit OpenPGP. Vielleicht ist ja jemand so freundlich mir zu helfen.

    Angezeigte Fehlermeldung: "Fehler - geheimer Schlüssel wird zur Entschlüsselung benötigt; klicken Sie bitte auf das Zeichen mit dem Schlüssel für Details":

    Quote

    OpenPGP-Sicherheitsinfo:

    Fehler - geheimer Schlüssel wird zur Entschlüsselung benötigt

    gpg Kommandozeile und Ausgabe:
    /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -d --passphrase-fd 0 --no-use-agent
    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID soundso, erzeugt 2008-01-28
    "Max Mustermann (Oeffentlich) <[email='max@mustermann.abc'][/email]>"
    gpg: Entschlüsselung fehlgeschlagen: Geheimer Schlüssel ist nicht vorhanden

    Die Konsole sagt:

    Quote


    Initializing Enigmail service ...
    EnigmailAgentPath=/usr/bin/gpg

    enigmail> /usr/bin/gpg --version --version --batch --no-tty --charset utf8
    gpg (GnuPG) 1.4.6
    Copyright (C) 2006 Free Software Foundation, Inc.
    This program comes with ABSOLUTELY NO WARRANTY.
    This is free software, and you are welcome to redistribute it
    under certain conditions. See the file COPYING for details.

    Home: ~/.gnupg
    Unterstützte Verfahren:
    Ãff.Schlüssel: RSA, RSA-E, RSA-S, ELG-E, DSA
    Verschlü.: 3DES, CAST5, BLOWFISH, AES, AES192, AES256, TWOFISH
    Hash: MD5, SHA1, RIPEMD160, SHA256, SHA384, SHA512, SHA224
    Komprimierung: nicht komprimiert, ZIP, ZLIB, BZIP2


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -d --passp
    hrase-fd 0 --no-use-agent
    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID soundso, erzeugt 2008-01-
    28
    "Max Mustermann (Oeffentlich) <[email='max@mustermann.abc'][/email]>"
    gpg: Entschlüsselung fehlgeschlagen: Geheimer Schlüssel ist nicht vorhanden
    enigmail.js: Enigmail.decryptMessageEnd: Error in command execution

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -d --passp
    hrase-fd 0 --no-use-agent
    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID sosundso, erzeugt 2008-01-
    28
    "Max Mustermann (Oeffentlich) <[email='max@mustermann.abc'][/email]>"
    gpg: Entschlüsselung fehlgeschlagen: Geheimer Schlüssel ist nicht vorhanden
    enigmail.js: Enigmail.decryptMessageEnd: Error in command execution

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --with-fin
    gerprint --fixed-list-mode --with-colons --list-keys


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --with-fin
    gerprint --fixed-list-mode --with-colons --list-secret-keys


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xC0B2CB0E1C01E5CD


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --with-fin
    gerprint --fixed-list-mode --with-colons --list-secret-keys


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0x3DE9ECC7AF5366AF


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --with-fin
    gerprint --fixed-list-mode --with-colons --list-secret-keys


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xC0B2CB0E1C01E5CD


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xC0B2CB0E1C01E5CD


    enigmail> /usr/bin/gpg --charset utf8 --no-tty --status-fd 1 --logger-fd 1 --co
    mmand-fd 0 --ask-cert-level --edit-key C0B2CB0E1C01E5CD trust

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --with-fin
    gerprint --fixed-list-mode --with-colons --list-keys
    gpg: "Trust-DB" wird überprüft
    gpg: 3 marginal-needed, 1 complete-needed, PGP Vertrauensmodell
    gpg: Tiefe: 0 gültig: 3 signiert: 0 Vertrauen: 0-, 0q, 0n, 0m, 0f, 3u
    gpg: nächste "Trust-DB"-Pflichtüberprüfung am 2012-10-31

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --with-fin
    gerprint --fixed-list-mode --with-colons --list-secret-keys

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --keyserve
    r pool.sks-keyservers.net --recv-keys 0xC0B2CB0E1C01E5CD

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xC0B2CB0E1C01E5CD


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0x3DE9ECC7AF5366AF


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xC0B2CB0E1C01E5CD


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xEDE1E2A87A79F22B


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 --fixed-li
    st-mode --with-colons --with-fingerprint --list-sig 0xC0B2CB0E1C01E5CD


    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -d --passp
    hrase-fd 0 --no-use-agent
    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID soundso, erzeugt 2008-01-
    28
    "Max Mustrermann (Oeffentlich) <[email='max@mustermann.abc'][/email]>"
    gpg: Entschlüsselung fehlgeschlagen: Geheimer Schlüssel ist nicht vorhanden
    enigmail.js: Enigmail.decryptMessageEnd: Error in command execution

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -d --passp
    hrase-fd 0 --no-use-agent
    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID soundso, erzeugt 2008-01-
    28
    "Max Mustermann (Oeffentlich) <[email='max@mustermann.abc'][/email]>"
    gpg: Entschlüsselung fehlgeschlagen: Geheimer Schlüssel ist nicht vorhanden
    enigmail.js: Enigmail.decryptMessageEnd: Error in command execution

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -d --passp
    hrase-fd 0 --no-use-agent
    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID soundso, erzeugt 2008-01-
    28
    "Max Mustermann (Oeffentlich) <[email='max@mustermann.abc'][/email]>"
    gpg: Entschlüsselung fehlgeschlagen: Geheimer Schlüssel ist nicht vorhanden
    enigmail.js: Enigmail.decryptMessageEnd: Error in command execution

    enigmail> /usr/bin/gpg --charset utf8 --batch --no-tty --status-fd 2 -a --expor
    t 0xC0B2CB0E1C01E5CD

    Display More

    Der Absender hat meinen öffentlichen Schlüsseln erhalten, ich seinen öffentlichen ebenso. Benutzer-Vertrauen habe ich auf "volles Vertrauen" festgelegt.

    Ich nutze Thunderbird Version 2.0.0.6 (20070728) (Linux) / Enigmail 0.95.6

    Was läuft falsch? Weiß jemand Rat?

  • Karla
    Member
    Posts
    222
    Member since
    9. Dec. 2003
    • February 21, 2008 at 5:00 PM
    • #2

    Hallo,

    laut der Fehlermeldung wird kein passender secret key gefunden. Wurde die Email eventuell mit dem falschen public key verschlüsselt, zu dem Du keinen secret key hast? Bist Du im Besitz eines Schlüsselpaares mit der "ID soundso" ?

    Karla

  • Silberdrache
    Junior Member
    Posts
    3
    Member since
    21. Feb. 2008
    • February 21, 2008 at 6:00 PM
    • #3

    Hallo Karla,

    und danke für Deine Unterstützung.

    Quote from "Karla"

    Hallo,

    laut der Fehlermeldung wird kein passender secret key gefunden. Wurde die Email eventuell mit dem falschen public key verschlüsselt, zu dem Du keinen secret key hast? Bist Du im Besitz eines Schlüsselpaares mit der "ID soundso" ?

    Nein, die angegebe ID gehört nicht zu meinen Schlüsseln.

    Quote

    gpg: verschlüsselt mit 2048-Bit ELG-E Schlüssel, ID XXXXXXXX, erzeugt 2008-01-
    28

    Würde in der o. a. Zeile dann unter XXXXXXXX die ID MEINES Schlüsseln stehen müssen oder des geheimen Schlüssels des Absenders?

    Meinen öffentlichen Schlüssel habe ich ihm natürlich per Mail zugeschickt und eigentlich gehe ich davon aus daß er ihn verwendet hat.

  • Karla
    Member
    Posts
    222
    Member since
    9. Dec. 2003
    • February 21, 2008 at 9:40 PM
    • #4

    Hallo,

    Quote from "Silberdrache"

    Würde in der o. a. Zeile dann unter XXXXXXXX die ID MEINES Schlüsseln stehen müssen oder des geheimen Schlüssels des Absenders?

    Da sollte die ID deines Schlüssel(-paares) stehen.
    [edit] Wie ich vorhin übersehen habe, ist der Schlüssel mit der ID XXXXXX auf die Emailadresse "max@mustermann.abc" ausgestellt. Das sollte deine Adresse sein. [/edit]

    Wie Du der Fehlermeldung entnehmen kannst, wurde die Nachricht mit dem Schlüssel mit dieser ID verschlüsselt, das Problem kann also nichts mit dem geheimen Schlüssel des Absenders zu tun haben.

    Grüsse
    Karla

  • Vic~
    Guest
    • February 22, 2008 at 5:58 PM
    • #5

    Hallo,

    und *Hüstel* ! :gruebel:
    Da wurde also "mal wieder" nicht der Fingerabdruck gegenseitig überprüft. [<--WICHTIG! ]
    Ansonsten wäre das Problem an sich gar nicht entstanden!
    {Ich weiß ja, daß ich jetzt wieder als übervorsichtiger Meckerer da stehe; aber IMCO ist Verschlüsselung halt eben *nur* mit einem Mindestmaß an Ernsthaftigkeit durchführbar!; wie man ja hier wieder sieht ...}

    Silberdrache gehe mal ganz simpel & logisch vor:
    Zunächst verschlüsselst Du irgend eine x-beliebige Datei auf Deinem PC und entschlüsselst sie auch wieder.
    Klappt das dann sende DIR selbst eine verschlüsselte e-mail, die Du dann (hoffentlich) auch wieder erfolgreich entschlüsseln kannst.

    Sodann hast Du zumindest ein Schlüsselpaar das funktioniert. :top:
    Den public-key gibst Du dann großzügig weiter und überprüft [bitte] mit *jedem* Kontakt später den "fingerprint". ;)

    So einfach ist es!
    MfG ... Vic

  • Silberdrache
    Junior Member
    Posts
    3
    Member since
    21. Feb. 2008
    • February 23, 2008 at 9:56 AM
    • #6

    Danke nochmal für die Unterstützung.

    Inzwischen hat es geklappt, der Fehler lag wohl nicht bei mir sondern bei meinem Kommunikationspartner.

  • Vic~
    Guest
    • February 23, 2008 at 5:20 PM
    • #7

    Hallo Silberdrache,

    ja Verschlüsselung ist etwas was nur mit einem "funktionalen" Gegenüber klappt! :knuddel: - Gut, daß es jetzt geht.

    Danke für Deine Rückmeldung und das Kennzeichnen des Threads als *erledigt*!

    MfG ... Vic

  • Thunder August 30, 2020 at 2:36 PM

    Moved the thread from forum OpenPGP Verschlüsselung & Unterschrift to forum OpenPGP & Enigmail in Thunderbird-Versionen bis 68.*.
  • Community-Bot September 3, 2024 at 7:20 PM

    Closed the thread.

Current app version

  • Thunderbird 155.0.1 veröffentlicht

    Thunder September 10, 2026 at 9:46 PM

Current 153 ESR version

  • Thunderbird 153.2.0 ESR veröffentlicht

    Thunder September 2, 2026 at 5:55 PM

Current 140 ESR version

  • Thunderbird 140.15.0 ESR veröffentlicht

    Thunder September 2, 2026 at 6:01 PM

No Advertisements

There are no advertisements here. Maybe you give the website owner (Alexander Ihrig - aka "Thunder") instead something to be able to finance these sites in the long run. Many Thanks!

Thank you for the support!

Coffee to be spent?

Donate now via Paypal*

*Forwarding to PayPal.Me

Thunderbird Mail DE
  1. Imprint & Contact
  2. Privacy Policy
    1. Cookie Policy
  3. Terms of Use
  4. Donation Call for Thunderbird
Help for this website
  • All website support articles
  • How to use website search
  • How to create a forums user account
  • How to create and edit a forums thread
  • How to reset your forums password
Copyright © 2003-2026 Thunderbird Mail DE

You are NOT on an official page of the Mozilla Foundation. Mozilla®, mozilla.org®, Firefox®, Thunderbird™, Bugzilla™, Sunbird®, Seamonkey®, XUL™ and the Thunderbird logo are (among others) registered trademarks of the Mozilla Foundation.

Powered by WoltLab Suite™